==> haskell-echo-0.1.3-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-echo.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: echo
version: 0.1.3
id: echo-0.1.3-BlErO49OOLiLJPizijFtq4
key: echo-0.1.3-BlErO49OOLiLJPizijFtq4
license: BSD3
copyright: (C) 2016-2017 Ryan Scott
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
stability: Provisional
homepage: https://github.com/RyanGlScott/echo
synopsis: A cross-platform, cross-console way to handle echoing terminal input
description:
    The @base@ library exposes the @hGetEcho@ and @hSetEcho@ functions
    for querying and setting echo status, but unfortunately, neither
    function works with MinTTY consoles on Windows. This is a serious
    issue, since @hGetEcho@ and @hSetEcho@ are often used to disable
    input echoing when a program prompts for a password, so many
    programs will reveal your password as you type it on MinTTY!
    .
    This library provides an alternative interface which works
    with both MinTTY and other consoles. An example is included
    which demonstrates how one might prompt for a password using
    this library. To build it, make sure to configure with the
    @-fexample@ flag.
category: System
author: Ryan Scott
exposed: True
indefinite: False
exposed-modules:
    System.IO.Echo System.IO.Echo.Internal
abi: 97b9392e1c806c3b81bae806920bf1be
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/echo-0.1.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/echo-0.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/echo-0.1.3
hs-libraries: HSecho-0.1.3-BlErO49OOLiLJPizijFtq4
depends:
    base-4.10.1.0 process-1.6.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
haddock-interfaces: /usr/share/doc/haskell-echo/html/echo.haddock
haddock-html: /usr/share/doc/haskell-echo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-echo-0.1.3-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-echo.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: echo
version: 0.1.3
id: echo-0.1.3-G7cuM0pWhoYJlNCMI5dtUe
key: echo-0.1.3-G7cuM0pWhoYJlNCMI5dtUe
license: BSD-3-Clause
copyright: (C) 2016-2017 Ryan Scott
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
author: Ryan Scott
stability: Provisional
homepage: https://github.com/RyanGlScott/echo
synopsis: A cross-platform, cross-console way to handle echoing terminal input
description:
    The @base@ library exposes the @hGetEcho@ and @hSetEcho@ functions
    for querying and setting echo status, but unfortunately, neither
    function works with MinTTY consoles on Windows. This is a serious
    issue, since @hGetEcho@ and @hSetEcho@ are often used to disable
    input echoing when a program prompts for a password, so many
    programs will reveal your password as you type it on MinTTY!
    .
    This library provides an alternative interface which works
    with both MinTTY and other consoles. An example is included
    which demonstrates how one might prompt for a password using
    this library. To build it, make sure to configure with the
    @-fexample@ flag.
category: System
abi: 4bb5af81cbf7430375f94e97b0be40d0
exposed: True
exposed-modules:
    System.IO.Echo System.IO.Echo.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/echo-0.1.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/echo-0.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/echo-0.1.3
hs-libraries: HSecho-0.1.3-G7cuM0pWhoYJlNCMI5dtUe
depends:
    base-4.11.1.0 process-1.6.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
haddock-interfaces: /usr/share/doc/haskell-echo/html/echo.haddock
haddock-html: /usr/share/doc/haskell-echo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
